@@ -10,6 +10,8 @@ sub run {
         print "You're not following $nick.\n";
         return 1;
     }
+    $self->add_metadata( 'unfollow', $nick, $self->following->{$nick} )
+      if $self->write_metadata;
     delete $self->following->{$nick};
     $self->sync;
     print "You've unfollowed $nick.\n";
